pub fn check_position_reconciliation(
report: &PositionStatusReport,
cached_signed_qty: Decimal,
size_precision: Option<u8>,
) -> boolExpand description
Generates the appropriate order events for an external order and order status report.
After creating an external order, we need to transition it to its actual state based on the order status report from the venue. For terminal states like Canceled/Expired/Filled, we return multiple events to properly transition